"use client";
import { useSearchParams } from "next/navigation";
import { marked } from "marked";
import DOMPurify from "dompurify"; // Prevents XSS attacks
import Image from "next/image";
import { useEffect, useState, useRef } from "react";

const ArticleOutput = () => {
  const searchParams = useSearchParams();
  const rawContent = searchParams.get("content") || "⚠️ No Output generated.";

  
  const [parsedContent, setParsedContent] = useState("");
  
  // Specify the type for contentRef
  const contentRef = useRef<HTMLDivElement | null>(null); // Type reference here

  useEffect(() => {
    const parseMarkdown = async () => {
      const html = await marked.parse(rawContent); // Await the Promise
      const sanitizedHtml = DOMPurify.sanitize(html); // Sanitize the HTML content

      // Apply custom styles to ensure only headings and bold tags are styled
      setParsedContent(sanitizedHtml);
    };

    parseMarkdown();
  }, [rawContent]);

//   const copyToClipboard = async () => {
//     if (contentRef.current) {
//       // Get the HTML content from the div
//       const contentToCopy = contentRef.current.innerHTML;
      
//       // Create a temporary textarea to hold the content and copy it
//       const textarea = document.createElement('textarea');
//       textarea.value = contentToCopy;
//       document.body.appendChild(textarea);
//       textarea.select();
//       document.execCommand('copy');
//       document.body.removeChild(textarea);

//       setIsCopied(true);
//       setTimeout(() => setIsCopied(false), 1500);
//     }
//   };

  return (
    <div className="col-lg-6 col-12 mt-4">
      <div className="custom-block custom-block-overlay">
        <div className="d-flex flex-column h-100">
          {/* Background Image */}
          <Image
            src="/images/businesswoman-using-tablet-analysis.jpg"
            layout="fill"
            objectFit="cover"
            className="z-n1"
            alt="Background"
            priority
          />

          <h4 className="text-primary">Generated Article</h4>

          {/* AI Generated Article Display */}
          <div className="border rounded p-3 bg-light position-relative text-start">
            {/* Copy Button */}
            {/* <button 
              className="btn btn-sm btn-outline-primary absolute top-0 right-0 m-2"
              onClick={copyToClipboard}
            >
              {isCopied ? "✅ Copied" : "📋 Copy"}
            </button> */}

            {/* Formatted Content */}
            <div
              ref={contentRef} // Assign the ref to the content div
              className="max-h-[600px] overflow-y-auto p-3 bg-white rounded-md text-left text-[16px] leading-relaxed scrollbar-thin scrollbar-thumb-gray-400 scrollbar-track-gray-100"
              dangerouslySetInnerHTML={{ __html: parsedContent }} 
            ></div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default ArticleOutput;
